# CMF imports
from Products.CMFCore import permissions

# Archetypes imports
from Products.Archetypes.atapi import *

# Product imports
from Products.InstantMessage.config import PROJECTNAME
from Products.InstantMessage.config import MESSAGE_PRIORITIES


# Schema definition
schema = BaseSchema.copy() +  Schema((

  StringField('priority',
              vocabulary = MESSAGE_PRIORITIES,
              default = 'normal',
              widget = SelectionWidget(label = 'Priority'),
             ),

  TextField('body',
            searchable = 1,
            required = 1,
            allowable_content_types = ('text/plain',
                                       'text/structured',
                                       'text/html',),
            default_output_type = 'text/x-html-safe',
            widget = RichWidget(label = 'Message Body'),
           ),

))


class InstantMessage(BaseContent):
    """An Archetype for an InstantMessage application"""

    schema = schema

    portal_type = meta_type = 'InstantMessage'
    archetype_name = 'Instant Message'
    
    _at_rename_after_creation = True
    
    actions = ({
        'id'          : 'view',
        'name'        : 'View',
        'action'      : 'string:${object_url}',
        'permissions' : (permissions.View,)
         },
        {
        'id'          : 'edit',
        'name'        : 'Edit',
        'action'      : 'string:${object_url}/edit',
        'permissions' : (permissions.ModifyPortalContent,),
         },
        {
        'id'          : 'metadata',
        'name'        : 'Properties',
        'action'      : 'string:${object_url}/properties',
        'permissions' : (permissions.ModifyPortalContent,),
         },
        )

    aliases = {
        '(Default)'  : 'instantmessage_view',
        'view'       : 'instantmessage_view',
        'edit'       : 'base_edit',
        'properties' : 'base_metadata',
        }


registerType(InstantMessage, PROJECTNAME)

